@@ -72,28 +72,10 @@ class Select2ModelFieldMixin(Select2FieldMixin):
 
     def _get_choices(self):
         if hasattr(self, '_choices'):
-            if not self._choices:
-                # Create an empty iterator for choices
-                def choices():
-                    return
-                    yield
-                self._choices = choices()
             return self._choices
         return self.choice_iterator_cls(self)
 
-    # def _set_choices(self, value):
-    #     choices = list(value)
-    #     if not choices:
-    #         def _choices():
-    #             return
-    #             yield
-    #         choices = _choices()
-    #     # Setting choices also sets the choices on the widget.
-    #     self._choices = self.widget.choices = choices
-    #
-    # choices = property(_get_choices, _set_choices)
 
-    
 class ModelChoiceField(Select2ModelFieldMixin, forms.ModelChoiceField):
 
     widget = Select
